import { ScrollView, StyleSheet, TouchableOpacity, View } from 'react-native'
import React, { useState } from 'react'
import { SafeAreaView } from 'react-native-safe-area-context'
import colors from '../../constants/colors'
import { PaperProvider, TextInput } from 'react-native-paper'
import { horizontalScale, moderateScale, verticalScale } from '../../constants/metrics'
import IonIcon from 'react-native-vector-icons/Ionicons'
import fonts from '../../constants/fonts'
import {navigateToListViewPage} from '../../utils/functions'
import CategorySearchSection from '../../components/organisms/Sections/CategorySearchSection'
import RecentSearchesSection from '../../components/organisms/Sections/RecentSearchesSection'

const SearchPage = props => {

  const {
    navigation,
    route
  } = props

  const [searchText, setSearchText] = useState("")

  // * Filters Modal
  const [isFiltersVisible, setFiltersVisible] = useState(false);
  const showFilters = () => setFiltersVisible(true);
  const hideFilters = () => setFiltersVisible(false);

  const styles = StyleSheet.create({
    container: {
      backgroundColor: colors().dominant,
      minHeight: '100%',
      maxHeight: 'auto'
    },
    inputTextContainer: {
      backgroundColor: colors().dominant,
      paddingHorizontal: horizontalScale(16),
      paddingVertical: verticalScale(16),
      flexDirection: 'row',
      alignItems: 'center',
      maxWidth: '100%'
    },
    utilContainer: {
      flexDirection: 'row',
      gap: 8,
      alignItems: 'center'
    },
    listItemText: {
      fontFamily: fonts.type.medium,
      fontSize: moderateScale(14),
      color: colors().recessive
    },
    listItem: {
      paddingVertical: verticalScale(0)
    }
  })

  const onSearch = () => {
    navigation.push('SearchListPage', { query: searchText })
  }

  return (
    <PaperProvider>
      <SafeAreaView style={styles.container}>
        <ScrollView>
          <View style={styles.inputTextContainer}>
            <TextInput
              returnKeyType='search'
              editable
              mode='outlined'
              placeholder='Search Text'
              placeholderTextColor={colors().grayShade_300}
              dense
              style={{
                backgroundColor: colors().grayShade_500,
                paddingVertical: moderateScale(4),
                flex: 1

              }}
              contentStyle={{
                fontSize: moderateScale(16),
                fontFamily: fonts.type.medium,
                // height: moderateScale(16),
              }}
              outlineStyle={{
                borderColor: colors().dominant_variant,
                borderRadius: moderateScale(8),
                borderWidth: moderateScale(1),
              }}
              cursorColor={colors().primaryColor}
              right={() => <TouchableOpacity onPress={() => navigateToListViewPage(navigation, 'search', searchText)}><IonIcon name="search" color={colors().grayShade_200} size={moderateScale(8)} /></TouchableOpacity>}
              onSubmitEditing={onSearch}
            />
          </View>
          <RecentSearchesSection navigation={navigation} route={route} />
          <CategorySearchSection navigation={navigation} route={route} />
        </ScrollView>
      </SafeAreaView>
    </PaperProvider>
  )
}

export default SearchPage

